@@ -1,7 +1,7 @@
 /* AstroChart.m
  * The circular Astrology chart
  *
- * Copyright (C) 1998-2012 by vhf interservice GmbH
+ * Copyright (C) 1998-2014 by Georg Fleischmann
  * Author:   Georg Fleischmann
  *
  * created:  1998-12-19
@@ -11,22 +11,22 @@
  *           2009-04-01 (radix: no date: draw composite only)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.de http://www.cenon.info
  */
 
 #include <AppKit/AppKit.h>
@@ -55,9 +55,9 @@
 #define SCALE_MAX	(SCALE_MIN * 2.0)
 #define SYMBOL_SIZE	0.12
 #define STAR_SIZE	0.25 //0.22
-#define FONT_SIZE	10.0	// fix
-#define LINE_HEIGHT	11.0	// fix
-#define TAB_SPACING	32.0	// fix
+#define FONT_SIZE	10.0	// absolute
+#define LINE_HEIGHT	11.0	// absolute
+#define TAB_SPACING	32.0	// absolute
 
 /* Private methods
  */
@@ -72,7 +72,7 @@
 }
 - (id)initWithView:(DocView*)aView
 {
-    [super init];
+    self = [super init];
     view = [aView retain];
     divider = 1;
     return self;
@@ -433,9 +433,9 @@ typedef enum
 {
     if ( dividerDict )
     {   //NSString    *sym = [symbols objectForKey:planet];
-        int         ix   = [[ephemeris objectNames] indexOfObject:planet];
-        NSString    *sym = [[ephemeris objectSymbols] objectAtIndex:ix];
-        BOOL        scale= [dividerDict intForKey:@"scale"];
+        int         ix    = [[ephemeris objectNames] indexOfObject:planet];
+        NSString    *sym  = [[ephemeris objectSymbols] objectAtIndex:ix];
+        BOOL        scale = [dividerDict intForKey:@"scale"];
 
         if ( [dividerDict objectForKey:sym] )
         {   int div = [dividerDict intForKey:sym];
@@ -481,8 +481,8 @@ typedef enum
     [planets addObjectsFromArray:Prefs_Objects];
 
     [ephemeris setMeanNodes:Prefs_MeanNodes];
-    degreeDict   = [ephemeris objectDictAtUTC:utc lat:latitude lon:longitude elev:0.0
-                                  topocentric:Prefs_Topocentric];
+    degreeDict   = [ephemeris objectDictAtUTC:utc lat:latitude lon:longitude elev:0.0 topocentric:Prefs_Topocentric
+                                 heliocentric:Prefs_Heliocentric equatorial:Prefs_Equatorial];
     if (Prefs_ACFix)
         rotateAC = 180.0 - [degreeDict floatForKey:@"AC"];	// rotation of chart
     nodeDict     = [ephemeris currentNodeDict];
@@ -569,6 +569,7 @@ typedef enum
             line = [VLine lineWithPoints:p0 :p1];
             [line setAngle:-angle withCenter:cp];
             [line setColor:color];
+            //[line setWidth:0.5];  // FIXME: 0.3 good for printing, 1.0 = good for screen, 0.0 = good on screen, printing ???
             [group addObject:line];
 
             string = (retro && v < 0.0) ? (NSString*)[NSString stringWithFormat:@"%@X", planetSymbol(planet)]
@@ -1094,7 +1095,9 @@ typedef enum
     NSString        *dateFormat = [Prefs_DateFormat stringByAppendingFormat:@" %%H:%%M %%z"];
 
     [(utc = [[date copy] autorelease]) setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
-    degreeDict = [ephemeris objectDictAtUTC:utc];
+    //degreeDict = [ephemeris objectDictAtUTC:utc];
+    degreeDict = [ephemeris objectDictAtUTC:utc lat:latitude lon:longitude elev:0.0 topocentric:Prefs_Topocentric
+                               heliocentric:Prefs_Heliocentric equatorial:Prefs_Equatorial];
 
     /* house cusps */
     {   int     houseCnt = 12;
@@ -1246,8 +1249,12 @@ typedef enum
     [planetsC addObjectsFromArray:Prefs_Objects];	// Planets 2 (inside)
 
     if (gmtH)
-        degreeDictH = [ephemeris objectDictAtUTC:gmtH lat:latitudeH lon:longitudeH elev:0.0 topocentric:Prefs_Topocentric];
-    degreeDictC = [ephemeris objectDictAtUTC:gmtC lat:latitudeC lon:longitudeC elev:0.0 topocentric:Prefs_Topocentric];
+        degreeDictH = [ephemeris objectDictAtUTC:gmtH lat:latitudeH lon:longitudeH elev:0.0
+                                     topocentric:Prefs_Topocentric
+                                    heliocentric:Prefs_Heliocentric equatorial:Prefs_Equatorial];
+    degreeDictC = [ephemeris objectDictAtUTC:gmtC lat:latitudeC lon:longitudeC elev:0.0
+                                 topocentric:Prefs_Topocentric
+                                heliocentric:Prefs_Heliocentric equatorial:Prefs_Equatorial];
 
     /*
      * Tansite aspect table between horoscope and composite
@@ -1870,7 +1877,7 @@ typedef enum
     /* get positions
      */
     if ([layerList count] <= 1)		// no way
-    {   NSLog(@"Not enough layers (%lu) to calculate chart !", [layerList count]);
+    {   NSLog(@"Not enough layers (%lu) to calculate chart !", (unsigned long)[layerList count]);
         return;
     }
     else if ([layerList count] == 2)	// use defaults
@@ -1982,18 +1989,21 @@ typedef enum
         /* give other modules a chance to add their stuff
          */
         infoDict = [NSMutableDictionary dictionaryWithObjectsAndKeys:
-                    layerList,                                  @"layerList",
-                    layer,                                      @"layerChart",
-                    [NSNumber numberWithFloat:rotateAC],        @"rotateAC",
-                    title,                                      @"title",
-                    utc,                                        @"date",
-                    [NSNumber numberWithFloat:latitude],        @"lat",
-                    [NSNumber numberWithFloat:longitude],       @"lon",
-                    propertyListFromNSPoint(cp),                @"center",
-                    [NSNumber numberWithFloat:radius],          @"radius",
-                    [NSNumber numberWithFloat:radius*RADIUS_3], @"radiusComposite",
-                    [NSNumber numberWithFloat:radius*RADIUS_4], @"radiusCenter",
-                    composite,                                  @"composite", nil];
+                    layerList,                                      @"layerList",
+                    layer,                                          @"layerChart",
+                    [NSNumber numberWithFloat:rotateAC],            @"rotateAC",
+                    title,                                          @"title",
+                    utc,                                            @"date",
+                    [NSNumber numberWithFloat:latitude],            @"lat",
+                    [NSNumber numberWithFloat:longitude],           @"lon",
+                    propertyListFromNSPoint(cp),                    @"center",
+                    [NSNumber numberWithFloat:radius],              @"radius",
+                    [NSNumber numberWithFloat:radius*RADIUS_2],     @"radiusScale",
+                    [NSNumber numberWithFloat:radius*RADIUS_3],     @"radiusComposite",
+                    [NSNumber numberWithFloat:radius*RADIUS_4],     @"radiusCenter",
+                    [NSNumber numberWithFloat:radius*SCALE_MIN],    @"scaleMin",
+                    [NSNumber numberWithFloat:radius*SCALE_MAX],    @"scaleMax",
+                    composite,                                      @"composite", nil];
         [notificationCenter postNotificationName:AstroAddChartParts
                                           object:self userInfo:infoDict];
 
@@ -2045,7 +2055,8 @@ typedef enum
 
                 if ( min > 10 )	// delta > 10 minutes -> calculate objects
                     [ephemeris objectDictAtUTC:dateI lat:latitude lon:longitude elev:0.0
-                                   topocentric:Prefs_Topocentric];
+                                   topocentric:Prefs_Topocentric
+                                  heliocentric:Prefs_Heliocentric equatorial:Prefs_Equatorial];
                 [infoDict setObject:dateI                          forKey:@"date"];
                 [infoDict setObject:propertyListFromNSPoint(cp)    forKey:@"center"];
                 [infoDict setObject:[NSNumber numberWithFloat:rad] forKey:@"radius"];
