@@ -1,29 +1,29 @@
 /* APSearch.m
  * Controls the chart generation
  *
- * Copyright (C) 2004-2009 by vhf interservice GmbH
+ * Copyright (C) 2004-2014 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * Created:  2004-05-20
  * Modified: 2009-02-22
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
 #include <VHFShared/vhfCommonFunctions.h>
@@ -155,7 +155,9 @@
     planet[1] = [planetList objectAtIndex:[planet2Popup indexOfSelectedItem]];
 
     if (!symbolFont)
-        [NSFont fontWithName:@"vhfAstro" size:12.0];
+        symbolFont = [NSFont fontWithName:@"cenAstro" size:12.0];
+    if (!symbolFont)
+        symbolFont = [NSFont fontWithName:@"vhfAstro" size:12.0];
     if (!aspectList)
         aspectList = [NSMutableDictionary new];
 
@@ -174,6 +176,7 @@
             }
         [ephemerisSearch setTopocentricSearch:Prefs_Topocentric
                                           lat:[astroChart latitude] lon:[astroChart longitude] elev:0];
+        [ephemerisSearch setHeliocentricSearch:Prefs_Heliocentric];
         searchDict = [ephemerisSearch searchAspect:planet[0] :planet[1]
                                           dividers:dividers
                                       searchAngles:searchAngles searchMirrors:searchMirrors
