@@ -1,29 +1,29 @@
 /* AstroPrincipal.m
  * Commander of the Astrology module
  *
- * Copyright (C) 2003-2012 by Georg Fleischmann
+ * Copyright (C) 2003-2014 by Georg Fleischmann
  * Author:   Georg Fleischmann
  *
  * created:  2003-03-29
- * modified: 2012-08-15
+ * modified: 2014-11-20
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
- * License requires that the copyright notices and this notice
- * be preserved on all copies.
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the License
+ * requires that the copyright notices and this notice be
+ * preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
 #include <AppKit/AppKit.h>
@@ -164,16 +164,16 @@ NSString *stringFromDeg(float deg)
 
 
 /* init
- * modified: 2006-07-19
+ * modified: 2014-11-20
  */
 - init
 {   NSNotificationCenter	*notificationCenter = [NSNotificationCenter defaultCenter];
-    NSFileManager		*fileManager = [NSFileManager defaultManager];
+    NSFileManager           *fileManager = [NSFileManager defaultManager];
 #if !defined(GNUSTEP_BASE_VERSION) && !defined(__APPLE__)	// OpenStep 4.2
-    NSMenu			*toolMenu = [[[NSApp mainMenu] itemWithTag:MENU_TOOLS] target];
+    NSMenu                  *toolMenu = [[[NSApp mainMenu] itemWithTag:MENU_TOOLS] target];
 #else	// Apple, GNUstep
-    NSMenu			*toolMenu = [[[NSApp mainMenu] itemAtIndex:MENU_TOOLS-1] submenu];
-    NSMenu			*helpMenu = [[[NSApp mainMenu] itemAtIndex:MENU_HELP -1] submenu];
+    NSMenu                  *toolMenu = [[[NSApp mainMenu] itemAtIndex:MENU_TOOLS-1] submenu];
+    NSMenu                  *helpMenu = [[[NSApp mainMenu] itemAtIndex:MENU_HELP -1] submenu];
 #endif
 
     /* create HOME-Library entries, if they doesn't exist */
@@ -186,7 +186,7 @@ NSString *stringFromDeg(float deg)
         /* create "Cenon/Astro" */
         to = vhfPathWithPathComponents(path, MODULENAME, nil);
         if ( ![fileManager fileExistsAtPath:to] )
-            [fileManager createDirectoryAtPath:to attributes:nil];
+            [fileManager createDirectoryAtPath:to recursive:NO attributes:nil error:NULL];
 
         /* create folders + copy "Cenon/Astro/.../.dir.tiff" */
         for (i=0; i<3; i++)
@@ -205,9 +205,9 @@ NSString *stringFromDeg(float deg)
                     to   = vhfPathWithPathComponents(dir, @".dir.tiff", nil);
             }
             if ( dir && ![fileManager fileExistsAtPath:dir] )
-                [fileManager createDirectoryAtPath:dir attributes:nil];
+                [fileManager createDirectoryAtPath:dir recursive:NO attributes:nil error:NULL];
             if ( ![fileManager fileExistsAtPath:to] )
-                [fileManager copyPath:from toPath:to handler:nil];
+                [fileManager copyPath:from toPath:to error:NULL];
         }
     }
 
@@ -465,7 +465,7 @@ NSString *stringFromDeg(float deg)
                 break;
         }
         if ( i < 0 )
-        {   NSLog(@"AstroPrincipal: No document found with prefix '%@' to chart data!", CHART_PREFIX);
+        {   NSLog(@"AstroPrincipal: No document found with prefix '%@' to display data!", CHART_PREFIX);
             return;
         }
 
@@ -545,4 +545,9 @@ NSString *stringFromDeg(float deg)
         NSLog(@"AstroPrincipal (updateMapForDate), notification send with an object not a date!");
 }
 
+- (void)terminate
+{
+    //NSLog(@"AstroPrincipal terminated !");
+}
+
 @end
