@@ -8,22 +8,22 @@
  * modified: 2006-06-12 (LITTLE_ENDIAN)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
 #include <Foundation/Foundation.h> 
@@ -339,7 +339,7 @@ static char *AllocStr(char *str)
     // newStr = strdup(str);
     newStr = (char*)malloc(strlen(str)+1);
     if (newStr == NULL)
-        map_error("%s: out of memory\n", Pgm);
+        printf("%s: out of memory\n", Pgm);
     else
         strcpy(newStr, str);
     return (newStr);
@@ -356,7 +356,7 @@ static FILE *OpenFile(MapSet *ms, char *dir, char *fname, char *type)
     else
     {
 	fullname = (char *)malloc(strlen(dir)+strlen(fname)+2);
-	if (fullname == NULL) map_error("%s: out of memory\n", Pgm);
+	if (fullname == NULL) printf("%s: out of memory\n", Pgm);
 	sprintf(fullname, "%s/%s", dir, fname);
     }
     errno = 0;
@@ -364,7 +364,7 @@ static FILE *OpenFile(MapSet *ms, char *dir, char *fname, char *type)
     if (fp == NULL)
     {
 	if (ms->debug & D_FILES)
-        {   perror(fullname);
+    {   perror(fullname);
 	    fprintf(stderr, "%s: error %d opening %s\n", Pgm, errno, fullname);
 	}
 	return (NULL);
@@ -403,7 +403,7 @@ static void CloseOldFile(MapSet *ms)
 	}
     }
     if (oldG == generation)
-	map_error("%s: error: cannot find a file to close\n", Pgm);
+	printf("%s: error: cannot find a file to close\n", Pgm);
     CloseFile(ms, oldM);
 }
 
@@ -417,66 +417,66 @@ static void OpenMapFile(MapSet *ms, MapFile *mFile)
 
     while (mFile->file == NULL)
     {
-	if (mFile->file == NULL && (maxOpen == -1 || openCount < maxOpen))
+        if (mFile->file == NULL && (maxOpen == -1 || openCount < maxOpen))
         {
-	    mFile->file = OpenFile(ms, mFile->dir, mFile->name, "rb");
-	    if (mFile->file != NULL)
+            mFile->file = OpenFile(ms, mFile->dir, mFile->name, "rb");
+            if (mFile->file != NULL)
             {
-		++openCount;
-		if (mFile->header.segcount == -1)
+                ++openCount;
+                if (mFile->header.segcount == -1)
                 {
-		    GETLONG(mFile->header.magic, mFile->file);
-		    GETLONG(mFile->header.dictaddr, mFile->file);
-		    GETLONG(mFile->header.segcount, mFile->file);
-		    GETLONG(mFile->header.segsize, mFile->file);
-		    GETLONG(mFile->header.segmax, mFile->file);
-		    if (mFile->header.segcount * sizeof (struct segdict) !=
-				mFile->header.segsize)
+                    GETLONG(mFile->header.magic, mFile->file);
+                    GETLONG(mFile->header.dictaddr, mFile->file);
+                    GETLONG(mFile->header.segcount, mFile->file);
+                    GETLONG(mFile->header.segsize, mFile->file);
+                    GETLONG(mFile->header.segmax, mFile->file);
+                    if (mFile->header.segcount * sizeof (struct segdict) !=
+                        mFile->header.segsize)
                     {
-			if (ferror(mFile->file))
+                        if (ferror(mFile->file))
                         {
-			    perror(mFile->name);
-			    if (errno == EBADF)
+                            perror(mFile->name);
+                            if (errno == EBADF)
                             {
-				/* apparently too many open files, even though fopen() succeeded! */
-				maxOpen = openCount - FILE_RESERVE;
-				fprintf(stderr, "%s: setting -map_maxopen %d\n", Pgm, maxOpen);
-				CloseFile(ms, mFile);
-				--openCount;
-				mFile->header.segcount = -1;
-				continue;
-			    }
-			}
-			map_error("%s: incompatible file format: %s\n", Pgm, mFile->name);
-		    }
-		    if (ms->max_segcount < mFile->header.segcount)
-			ms->max_segcount = mFile->header.segcount;
-		    if (mFile->header.magic == CBD_MAGIC2)
+                                /* apparently too many open files, even though fopen() succeeded! */
+                                maxOpen = openCount - FILE_RESERVE;
+                                fprintf(stderr, "%s: setting -map_maxopen %d\n", Pgm, maxOpen);
+                                CloseFile(ms, mFile);
+                                --openCount;
+                                mFile->header.segcount = -1;
+                                continue;
+                            }
+                        }
+                        printf("%s: incompatible file format: %s\n", Pgm, mFile->name);
+                    }
+                    if (ms->max_segcount < mFile->header.segcount)
+                        ms->max_segcount = mFile->header.segcount;
+                    if (mFile->header.magic == CBD_MAGIC2)
                     {
-			GETLONG(mFile->header.maxlat, mFile->file);
-			GETLONG(mFile->header.minlat, mFile->file);
-			GETLONG(mFile->header.maxlong, mFile->file);
-			GETLONG(mFile->header.minlong, mFile->file);
-			GETLONG(mFile->header.features, mFile->file);
-			GETLONG(mFile->header.scale_shift, mFile->file);
-			GETLONG(mFile->header.lat_offset, mFile->file);
-			GETLONG(mFile->header.lng_offset, mFile->file);
-		    }
-		}
-		if (ms->debug & D_FILES)
-		    fprintf(stderr, "opened %s (%d/%d open)\n", mFile->name, openCount, maxOpen);
-		return;
-	    }
-	    if (errno != EMFILE)
+                        GETLONG(mFile->header.maxlat, mFile->file);
+                        GETLONG(mFile->header.minlat, mFile->file);
+                        GETLONG(mFile->header.maxlong, mFile->file);
+                        GETLONG(mFile->header.minlong, mFile->file);
+                        GETLONG(mFile->header.features, mFile->file);
+                        GETLONG(mFile->header.scale_shift, mFile->file);
+                        GETLONG(mFile->header.lat_offset, mFile->file);
+                        GETLONG(mFile->header.lng_offset, mFile->file);
+                    }
+                }
+                if (ms->debug & D_FILES)
+                    fprintf(stderr, "opened %s (%d/%d open)\n", mFile->name, openCount, maxOpen);
+                return;
+            }
+            if (errno != EMFILE)
             {
-		perror(mFile->name);
-		map_error("%s: error %d opening %s\n", Pgm, errno, mFile->name);
-	    }
-	}
-	/* try closing another open file */
-	CloseOldFile(ms);
-	--openCount;
-	if (maxOpen == -1)
+                perror(mFile->name);
+                printf("%s: error %d opening %s\n", Pgm, errno, mFile->name);
+            }
+        }
+        /* try closing another open file */
+        CloseOldFile(ms);
+        --openCount;
+        if (maxOpen == -1)
             maxOpen = openCount - FILE_RESERVE;
     }
 }
@@ -489,20 +489,20 @@ static MapFile *InitMapFile(MapSet *ms, char *dir, char *name)
     int		p;
 
     if (filePool == NULL)
-	filePool = (MapFile **)calloc(ms->maxMaps, sizeof(MapFile *));
+        filePool = (MapFile **)calloc(ms->maxMaps, sizeof(MapFile *));
     if (filePool == NULL)
-	map_error("%s: out of memory\n", Pgm);
+        printf("%s: out of memory\n", Pgm);
 
     /* check pool for matching file */
     for (p = 0; p < poolSize; ++p)
     {
-	mFile = filePool[p];
-	if (!strcmp(mFile->name, name) && !strcmp(mFile->dir, dir))
+        mFile = filePool[p];
+        if (!strcmp(mFile->name, name) && !strcmp(mFile->dir, dir))
         {
-	    if (ms->debug & D_FILES)
-	        fprintf(stderr, "found %s as pool file %d\n", name, p);
-	    return(mFile);
-	}
+            if (ms->debug & D_FILES)
+                fprintf(stderr, "found %s as pool file %d\n", name, p);
+            return(mFile);
+        }
     }
     /* allocate new MapFile and add it to the pool */
     mFile = (MapFile *)calloc(1, sizeof(MapFile));	/* fill with zeros */
@@ -512,7 +512,7 @@ static MapFile *InitMapFile(MapSet *ms, char *dir, char *name)
     mFile->file = NULL;			/* not open */
     mFile->header.dictaddr = 0;		/* not yet read */
     if (poolSize < ms->maxMaps)
-	filePool[poolSize++] = mFile;
+        filePool[poolSize++] = mFile;
     return(mFile);
 }
 
@@ -523,18 +523,18 @@ void map_read_profile(MapSet *ms, char *dirName, char *fileName)
     char	line[MAX_LINELEN];
 
     if (!strcmp(fileName, FNAME_STD))
-	fp = stdin;
+        fp = stdin;
     else
-	fp = OpenFile(ms, dirName, fileName, "r");
+        fp = OpenFile(ms, dirName, fileName, "r");
     if (fp == NULL)
-	map_error("unable to open file: %s\n", fileName);
+        printf("unable to open file: %s\n", fileName);
     if (ms->debug & D_VERBOSE)
     {
-	fprintf(stderr, "reading profile %s\n", fileName);
-	fflush(stderr);
+        fprintf(stderr, "reading profile %s\n", fileName);
+        fflush(stderr);
     }
     while (fscanf(fp, " %[^\n]\n", line) == 1)
-	map_read_profile_entry(ms, line);
+        map_read_profile_entry(ms, line);
     fclose(fp);
 } // end map_read_profile
 
@@ -549,52 +549,52 @@ void map_read_profile_entry(MapSet *ms, char *line)
     option = GetToken(line, "option expected");
     if (!strcmp(option, "-mapdir"))
     {
-	ms->mapDir = AllocStr(GetToken(NULL, option));
+        ms->mapDir = AllocStr(GetToken(NULL, option));
     }
     else if (!strcmp(option, "-resolution"))
     {
-	char *scaleName = GetToken(NULL, option);
-	for (ms->scaleI = 0; ms->scaleI < ms->scaleCount; ++ms->scaleI)
-	    if (!strcmp(scaleName, ms->scaleNames[ms->scaleI]))
+        char *scaleName = GetToken(NULL, option);
+        for (ms->scaleI = 0; ms->scaleI < ms->scaleCount; ++ms->scaleI)
+            if (!strcmp(scaleName, ms->scaleNames[ms->scaleI]))
             {
-		return;
-	    }
-	if (ms->scaleCount >= ms->maxScales)
-            map_error("%s: too many scales, increase -map_maxscales (currently %d)\n",
-		Pgm, ms->maxScales);
-	else
+                return;
+            }
+        if (ms->scaleCount >= ms->maxScales)
+            printf("%s: too many scales, increase -map_maxscales (currently %d)\n",
+                   Pgm, ms->maxScales);
+        else
         {
-	    ms->scaleI = ms->scaleCount++;
-	    ms->scaleNames[ms->scaleI] = AllocStr(scaleName);
-	    ms->autoRes[ms->scaleI] = ms->minRes[ms->scaleI] = 0.0;
-	    sscanf(GetToken(NULL, option), "%f", &ms->autoRes[ms->scaleI]);
-	    sscanf(GetToken(NULL, option), "%f", &ms->minRes[ms->scaleI]);
-	    if (ms->scaleI == 0 || ms->autoRes[ms->scaleI] < ms->minAuto)
+            ms->scaleI = ms->scaleCount++;
+            ms->scaleNames[ms->scaleI] = AllocStr(scaleName);
+            ms->autoRes[ms->scaleI] = ms->minRes[ms->scaleI] = 0.0;
+            sscanf(GetToken(NULL, option), "%f", &ms->autoRes[ms->scaleI]);
+            sscanf(GetToken(NULL, option), "%f", &ms->minRes[ms->scaleI]);
+            if (ms->scaleI == 0 || ms->autoRes[ms->scaleI] < ms->minAuto)
             {
-		ms->minAuto = ms->autoRes[ms->scaleI];
-		ms->minAutoI = ms->scaleI;
-	    }
-	    if (ms->debug & D_PROFILE)
+                ms->minAuto = ms->autoRes[ms->scaleI];
+                ms->minAutoI = ms->scaleI;
+            }
+            if (ms->debug & D_PROFILE)
             {   fprintf(stderr, "autoRes %g minRes %g, min: %s %g\n",
-			ms->autoRes[ms->scaleI], ms->minRes[ms->scaleI],
-			ms->scaleNames[ms->minAutoI], ms->minAuto);
-	    } // endif debug
-	}
+                        ms->autoRes[ms->scaleI], ms->minRes[ms->scaleI],
+                        ms->scaleNames[ms->minAutoI], ms->minAuto);
+            } // endif debug
+        }
     }
     else if (!strcmp(option, "-type"))
     {
-	char *typeName = GetToken(NULL, option);
-	for (i = 0; i < ms->mTypeCount; ++i)
-	    if (!strcmp(typeName, ms->mTypes[i]))
+        char *typeName = GetToken(NULL, option);
+        for (i = 0; i < ms->mTypeCount; ++i)
+            if (!strcmp(typeName, ms->mTypes[i]))
             {
-		ms->mapType = i;
-		return;
-	    }
-	if (ms->mTypeCount >= ms->maxTypes)
-	    map_error("%s: too many map types, increase -map_maxtypes (currently %d)\n",
-		Pgm, ms->maxTypes);
-	else
-	    ms->mTypes[ms->mapType = ms->mTypeCount++] = AllocStr(typeName);
+                ms->mapType = i;
+                return;
+            }
+        if (ms->mTypeCount >= ms->maxTypes)
+            printf("%s: too many map types, increase -map_maxtypes (currently %d)\n",
+                    Pgm, ms->maxTypes);
+        else
+            ms->mTypes[ms->mapType = ms->mTypeCount++] = AllocStr(typeName);
     }
     else if (!strcmp(option, "-min_features"))
     {
@@ -603,90 +603,90 @@ void map_read_profile_entry(MapSet *ms, char *line)
     }
     else if (!strcmp(option, "-suppress"))
     {
-	if (ms->suppressMasks[ms->mapType] == NULL)
-	    ms->suppressMasks[ms->mapType] = (long *)calloc(ms->maxScales, sizeof(long));
-	ms->suppressMasks[ms->mapType][ms->scaleI] = strtol(GetToken(NULL, option), NULL, 2);
-	ms->enforce_suppression[ms->mapType] = YES;
+        if (ms->suppressMasks[ms->mapType] == NULL)
+            ms->suppressMasks[ms->mapType] = (long *)calloc(ms->maxScales, sizeof(long));
+        ms->suppressMasks[ms->mapType][ms->scaleI] = strtol(GetToken(NULL, option), NULL, 2);
+        ms->enforce_suppression[ms->mapType] = YES;
     }
     else if (!strcmp(option, "-optional"))
     {
-	ms->optional[ms->mapType] = YES;
-	ms->enableMasks[ms->mapType] = 0;	// disable by default
+        ms->optional[ms->mapType] = YES;
+        ms->enableMasks[ms->mapType] = 0;	// disable by default
     }
     else if (!strcmp(option, "-color"))
     {
-	int cnum;
-	char *tok;
-	cnum = atoi(GetToken(NULL, option)) & 0xFF;
-	if (cnum >= ms->colors.length) ms->colors.length = cnum+1;
-	tok = GetToken(NULL, option);
-	if (!strcmp(tok, "dotted")) ms->patterns[cnum] = 1;
-	else if (!strcmp(tok, "dashed")) ms->patterns[cnum] = 2;
-	else if (!strcmp(tok, "dashdot")) ms->patterns[cnum] = 3;
-	else if (!strcmp(tok, "dashdotdotted")) ms->patterns[cnum] = 4;
-	else if (!strcmp(tok, "longdashed")) ms->patterns[cnum] = 5;
-	else ms->patterns[cnum] = 0;
-	ms->useColorPat[cnum] = !strcmp(GetToken(NULL, option), "and");
-	ms->colors.map[0][cnum] = strtol(GetToken(NULL, option), NULL, 0);
-	ms->colors.map[1][cnum] = strtol(GetToken(NULL, option), NULL, 0);
-	ms->colors.map[2][cnum] = strtol(GetToken(NULL, option), NULL, 0);
+        int cnum;
+        char *tok;
+        cnum = atoi(GetToken(NULL, option)) & 0xFF;
+        if (cnum >= ms->colors.length) ms->colors.length = cnum+1;
+        tok = GetToken(NULL, option);
+        if (!strcmp(tok, "dotted")) ms->patterns[cnum] = 1;
+        else if (!strcmp(tok, "dashed")) ms->patterns[cnum] = 2;
+        else if (!strcmp(tok, "dashdot")) ms->patterns[cnum] = 3;
+        else if (!strcmp(tok, "dashdotdotted")) ms->patterns[cnum] = 4;
+        else if (!strcmp(tok, "longdashed")) ms->patterns[cnum] = 5;
+        else ms->patterns[cnum] = 0;
+        ms->useColorPat[cnum] = !strcmp(GetToken(NULL, option), "and");
+        ms->colors.map[0][cnum] = strtol(GetToken(NULL, option), NULL, 0);
+        ms->colors.map[1][cnum] = strtol(GetToken(NULL, option), NULL, 0);
+        ms->colors.map[2][cnum] = strtol(GetToken(NULL, option), NULL, 0);
     }
     else if (!strcmp(option, "-grid"))
-	ms->gridColor = atoi(GetToken(NULL, option));
+        ms->gridColor = atoi(GetToken(NULL, option));
     else if (!strcmp(option, "-background"))
-	ms->bgColor = atoi(GetToken(NULL, option));
+        ms->bgColor = atoi(GetToken(NULL, option));
     else if (!strcmp(option, "-highlight"))
-	ms->highlight_color = atoi(GetToken(NULL, option));
+        ms->highlight_color = atoi(GetToken(NULL, option));
     else if (!strcmp(option, "-fatten_scale"))
     {
-	 float fatscale;
-	sscanf(GetToken(NULL, option), "%f", &fatscale);
-	ms->fatten_thresh = (long) ((1 << MAGSHIFT) / fatscale);
+        float fatscale;
+        sscanf(GetToken(NULL, option), "%f", &fatscale);
+        ms->fatten_thresh = (long) ((1 << MAGSHIFT) / fatscale);
     }
     else if (!strcmp(option, "-feature"))
     {
-	int featureNum = strtol(GetToken(NULL, option), NULL, 0);
-	if (ms->features[ms->mapType] == NULL)
-	    ms->features[ms->mapType] = (MapFeature *)calloc(MAX_FEATURE+1, sizeof(MapFeature));
-	ms->features[ms->mapType][featureNum].rank = featureNum;
-	ms->features[ms->mapType][featureNum].color = atoi(GetToken(NULL, option));
-	ms->features[ms->mapType][featureNum].line_width = atoi(GetToken(NULL, option));
-	ms->features[ms->mapType][featureNum].name = AllocStr(strtok(NULL, "\n"));
-	if (ms->maxFeature[ms->mapType] < featureNum)
-	    ms->maxFeature[ms->mapType] = featureNum;
+        int featureNum = strtol(GetToken(NULL, option), NULL, 0);
+        if (ms->features[ms->mapType] == NULL)
+            ms->features[ms->mapType] = (MapFeature *)calloc(MAX_FEATURE+1, sizeof(MapFeature));
+        ms->features[ms->mapType][featureNum].rank = featureNum;
+        ms->features[ms->mapType][featureNum].color = atoi(GetToken(NULL, option));
+        ms->features[ms->mapType][featureNum].line_width = atoi(GetToken(NULL, option));
+        ms->features[ms->mapType][featureNum].name = AllocStr(strtok(NULL, "\n"));
+        if (ms->maxFeature[ms->mapType] < featureNum)
+            ms->maxFeature[ms->mapType] = featureNum;
     }
     else if (!strcmp(option, "-map"))
     {   MapStruct *map;
-	char *str;
+        char *str;
 
-	if (ms->mCount >= ms->maxMaps)
-	    map_error("%s: too many maps, increase -map_maxmaps (currently %d)\n",
-		Pgm, ms->maxMaps);
-	map = &ms->maps[ms->mCount];
-	if (ms->mapType == -1)
-	    ms->mTypes[ms->mapType = ms->mTypeCount++] = DEF_MAPTYPE;
-	map->type = ms->mapType;
-	map->scaleI = ms->scaleI;
+        if (ms->mCount >= ms->maxMaps)
+            printf("%s: too many maps, increase -map_maxmaps (currently %d)\n",
+                    Pgm, ms->maxMaps);
+        map = &ms->maps[ms->mCount];
+        if (ms->mapType == -1)
+            ms->mTypes[ms->mapType = ms->mTypeCount++] = DEF_MAPTYPE;
+        map->type = ms->mapType;
+        map->scaleI = ms->scaleI;
 	
-	map->mfile = InitMapFile(ms, ms->mapDir,
-		AllocStr(GetToken(NULL, option)));
-	str = strtok(NULL, TOK_SEPS);
-	if (str != NULL) map->rank_offset = atoi(str);
-	map->uPerDeg = -1;			// not-loaded flag
-	map->mfile->header.segcount = -1;	// not-read flag
-	++ms->mCount;
+        map->mfile = InitMapFile(ms, ms->mapDir,
+                                     AllocStr(GetToken(NULL, option)));
+        str = strtok(NULL, TOK_SEPS);
+        if (str != NULL) map->rank_offset = atoi(str);
+        map->uPerDeg = -1;			// not-loaded flag
+        map->mfile->header.segcount = -1;	// not-read flag
+        ++ms->mCount;
     }
     else if (!strcmp(option, "-readprofile"))
-	map_read_profile(ms, ms->mapDir, GetToken(NULL, option));
+        map_read_profile(ms, ms->mapDir, GetToken(NULL, option));
     else if (!strcmp(option, "-ll_center"))
     {
-	sscanf(GetToken(NULL, option), "%f", &ms->def_centerLng);
-	sscanf(GetToken(NULL, option), "%f", &ms->def_centerLat);
+        sscanf(GetToken(NULL, option), "%f", &ms->def_centerLng);
+        sscanf(GetToken(NULL, option), "%f", &ms->def_centerLat);
     }
     else if (!strcmp(option, "-ll_extent"))
     {
-	sscanf(GetToken(NULL, option), "%f", &ms->def_showLng);
-	sscanf(GetToken(NULL, option), "%f", &ms->def_showLat);
+        sscanf(GetToken(NULL, option), "%f", &ms->def_showLng);
+        sscanf(GetToken(NULL, option), "%f", &ms->def_showLat);
     }
 } // end map_read_profile_entry
 
@@ -702,7 +702,7 @@ void map_load(MapSet *ms, int mapIndex)
     map->uSecShift = -(map->mfile->header.scale_shift);
     map->uPerDeg = SEC_PER_DEG << map->uSecShift;
     if (map->mfile->header.magic != CBD_MAGIC2)
-	map_error("%s: cannot read map format: %s\n", map->mfile->name);
+        printf("%s: cannot read map format: %s\n", map->mfile->name, "?");
     map->minSSec = U_TO_SEC(map, map->mfile->header.minlat);
     map->maxNSec = U_TO_SEC(map, map->mfile->header.maxlat);
     map->minWSec = U_TO_SEC(map, map->mfile->header.minlong);
@@ -718,14 +718,14 @@ void map_load(MapSet *ms, int mapIndex)
     if (ms->debug & D_READMAP)
     {   int i;
 
-	fprintf(stderr,
-	"%s contains %d blocks covering (%.2f%s %.2f%s) to (%.2f%s %.2f%s) features:",
-		map->mfile->name, (int)map->mfile->header.segcount,
-		LATLONGS_PRINTARGS(map->minLat, map->minLng),
-		LATLONGS_PRINTARGS(map->maxLat, map->maxLng));
-	for (i = 1; i <= 32; i++)
-	    if (map->mfile->header.features & (1<<(i-1))) fprintf(stderr, " %d", i);
-	fprintf(stderr, "\n");
+        fprintf(stderr,
+                "%s contains %d blocks covering (%.2f%s %.2f%s) to (%.2f%s %.2f%s) features:",
+                map->mfile->name, (int)map->mfile->header.segcount,
+                LATLONGS_PRINTARGS(map->minLat, map->minLng),
+                LATLONGS_PRINTARGS(map->maxLat, map->maxLng));
+        for (i = 1; i <= 32; i++)
+            if (map->mfile->header.features & (1<<(i-1))) fprintf(stderr, " %d", i);
+        fprintf(stderr, "\n");
     } // endif debug
 }
 
@@ -1977,11 +1977,11 @@ return;
  * map_init
  */
 MapSet *map_init(NSString *mapset)
-{   MapSet		*ms;
-    char		*defProfile;
-    int			i;
-    NSString		*path;
-    NSFileManager	*fileManager = [NSFileManager defaultManager];
+{   MapSet          *ms;
+    char            *defProfile;
+    int             i;
+    NSString        *path;
+    NSFileManager   *fileManager = [NSFileManager defaultManager];
 
     Pgm++;
     ms = (MapSet*)calloc(1, sizeof(MapSet));
@@ -1991,8 +1991,9 @@ MapSet *map_init(NSString *mapset)
     {   NSLog(@"CIAMap: No 'mapset' entry, using default 'world_8f6.mapset'");
         mapset = @"world_8f6.mapset";
     }
-    defProfile = calloc([mapset cStringLength]+1, sizeof(char));
-    [mapset getCString:defProfile];
+    defProfile = calloc([mapset length]+1, sizeof(char));
+    //[mapset getCString:defProfile];
+    [mapset getCString:defProfile maxLength:[mapset length]+1 encoding:NSUTF8StringEncoding];
 
     ms->maxMaps = MAX_MAPS;
     ms->maxTypes = MAX_TYPES;
@@ -2001,8 +2002,9 @@ MapSet *map_init(NSString *mapset)
 
     /* set the path to the map folder */
     path = [[[NSBundle bundleForClass:[CIAMap class]] resourcePath] stringByAppendingPathComponent:MAP_FOLDER];
-    ms->mapDir = calloc([path cStringLength]+1, sizeof(char));
-    [path getCString:ms->mapDir];
+    ms->mapDir = calloc([path length]+1, sizeof(char));
+    //[path getCString:ms->mapDir];
+    [path getCString:ms->mapDir maxLength:[path length]+1 encoding:NSUTF8StringEncoding];
     path = [path stringByAppendingPathComponent:mapset];
     if (![fileManager fileExistsAtPath:path])
         NSLog(@"map_init(): file does not exist '%@'", path);
