@@ -1,33 +1,34 @@
 /* CityManager.m
  * controller class and files owner of the CityPanel
  *
- * Copyright (C) 2003-2005 by vhf interservice GmbH
+ * Copyright (C) 2003-2014 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2003-06-29
  * modified: 2005-11-16 (use MODULENAME makro)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
 #include "CityManager.h"
 #include "../Cenon/VHFShared/VHFDictionaryAdditions.h"
+#include "../Cenon/VHFShared/VHFSystemAdditions.h"      // NSFileManagerAdditions
 #include "../Cenon/App.h"
 #include "../Cenon/functions.h"
 #include "../Cenon/messages.h"
@@ -332,12 +333,12 @@
     /* load states from UserLibrary */
     path = [NSString stringWithFormat:@"%@/Astro/%@", userLibrary(), CITIES_FOLDER];
     if ([fileManager fileExistsAtPath:path])
-        [folders addObjectsFromArray:[fileManager directoryContentsAtPath:path]];
+        [folders addObjectsFromArray:[fileManager contentsOfDirectoryAtPath:path]];
 
     /* add states from LocalLibrary, which are not in UserLibrary */
     path = [NSString stringWithFormat:@"%@/Astro/%@", localLibrary(), CITIES_FOLDER];
     if ([fileManager fileExistsAtPath:path])
-    {   NSArray	*states = [fileManager directoryContentsAtPath:path];
+    {   NSArray	*states = [fileManager contentsOfDirectoryAtPath:path];
         int	i, cnt;
 
         for (i=0, cnt=[states count]; i<cnt; i++)
@@ -373,10 +374,10 @@
 
     dir = [userLibrary() stringByAppendingPathComponent:MODULENAME];
     if (![fileManager fileExistsAtPath:dir])	// create Astro folder
-        [fileManager createDirectoryAtPath:dir attributes:nil];
+        [fileManager createDirectoryAtPath:dir recursive:NO attributes:nil error:NULL];
     dir = [dir stringByAppendingPathComponent:CITIES_FOLDER];
     if (![fileManager fileExistsAtPath:dir])	// create city folder
-        [fileManager createDirectoryAtPath:dir attributes:nil];
+        [fileManager createDirectoryAtPath:dir recursive:NO attributes:nil error:NULL];
 
     path = [dir stringByAppendingPathComponent:name];
     [cities writeToFile:path atomically:YES];
