@@ -1,33 +1,33 @@
 /* EphemerisSearch.h
  * search Ephemeris data
  *
- * Copyright (C) 2004-2006 by vhf interservice GmbH
+ * Copyright (C) 2004-2014 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2004-04-12
  * modified: 2006-01-27
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
-#ifndef VHF_H_EPHEMERISSEARCH
-#define VHF_H_EPHEMERISSEARCH
+#ifndef CEN_H_EPHEMERISSEARCH
+#define CEN_H_EPHEMERISSEARCH
 
 #include	"../Astro/SwissEphemeris.subproj/Ephemeris.h"
 
@@ -35,13 +35,13 @@
 typedef enum
 {
     /* single aspects (object1) */
-    S_ASPECT_LON		= 0,	// ecliptic longitude of objects
-    S_ASPECT_DEC		= 1,	// declination of objects
-    S_ASPECT_LOCAL		= 2,	// local topocentric position of objects
+    S_ASPECT_LON            = 0,	// ecliptic longitude of objects
+    S_ASPECT_DEC            = 1,	// declination of objects
+    S_ASPECT_LOCAL          = 2,	// local topocentric position of objects
 
     /* pair aspects (object1 + object2) */
-    S_ASPECT_ANGLE		= 3,	// angle  between objects (ecliptic lon)
-    S_ASPECT_MIRROR		= 4,	// mirror between objects (ecliptic lon)
+    S_ASPECT_ANGLE          = 3,	// angle  between objects (ecliptic lon)
+    S_ASPECT_MIRROR         = 4,	// mirror between objects (ecliptic lon)
     S_ASPECT_PARALLEL		= 5,	// parallel of objects (declination mirror)
     S_ASPECT_DEC_ANGLE		= 6,	// declination angle
     S_ASPECT_LOCAL_ANGLE	= 7,	// local angle  between objects (scale of current houses)
@@ -61,8 +61,8 @@ typedef enum
 
 typedef struct
 {
-    double	val;		// value
-    double	v;		// speed
+    double	val;        // value
+    double	v;          // speed
 } AstroAspectValue;
 
 @interface EphemerisSearch:NSObject
@@ -74,9 +74,9 @@ typedef struct
     SEL		progressAction;
 
     /* topocentric search */
-    BOOL	topocentricSearch;
-    float	topoLat, topoLon;	// latitude, longitude
-    int		topoElev;		// elevation
+    BOOL	topocentricSearch, heliocentricSearch, equatorialSearch;
+    float	topoLat, topoLon;   // latitude, longitude
+    int		topoElev;           // elevation
 }
 
 /* init */
@@ -84,6 +84,8 @@ typedef struct
 - (id)initWithEphemeris:(Ephemeris*)eph;
 - (void)setProgressTarget:(id)target action:(SEL)action;
 - (void)setTopocentricSearch:(BOOL)topoFlag lat:(float)lat lon:(float)lon elev:(int)elev;
+- (void)setHeliocentricSearch:(BOOL)helioFlag;
+- (void)setEquatorialSearch:(BOOL)equatorFlag;
 
 /* basic search for single aspect */
 - (NSArray*)searchFromDate:(NSCalendarDate*)dateFr toDate:(NSCalendarDate*)dateTo
@@ -106,4 +108,4 @@ typedef struct
 
 @end
 
-#endif	// VHF_H_EPHEMERISSEARCH
+#endif	// CEN_H_EPHEMERISSEARCH
