@@ -1,29 +1,30 @@
 /* EphemerisSearch.m
  * search Ephemeris data
  *
- * Copyright (C) 2004-2009 by vhf interservice GmbH
+ * Copyright (C) 2004-2014 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2004-04-12
- * modified: 2009-02-22
+ * modified: 2014-11-20 (-setHeliocentricSearch: added)
+ *           2014-01-04 (clean up)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
 #include <Foundation/Foundation.h>
@@ -88,7 +89,14 @@ static unsigned secsPerDegree[O_ARRAYSIZE] =		// average seconds per degree of a
         topoElev = elev;
     }
 }
-
+- (void)setHeliocentricSearch:(BOOL)helioFlag
+{
+    heliocentricSearch = helioFlag;
+}
+- (void)setEquatorialSearch:(BOOL)equatorFlag
+{
+    equatorialSearch = equatorFlag;
+}
 
 /* cycle length in minutes
  * created: 2006-01-10
@@ -157,7 +165,7 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
 
 /* return value of aspect
  * created:  2006-01-11 (from trader module)
- * modified: 2006-02-03
+ * modified: 2014-11-21
  */
 - (AstroAspectValue)valueOfAspect:(int)obj1 :(int)obj2 aspect:(SearchAspectType)asp
                            atDate:(NSCalendarDate*)date
@@ -187,8 +195,8 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
 
         eph = [ephemeris objectsAtJD:[ephemeris julianDayForDate:date bc:NO] flags:ephFlags
                              objects:ephObjIx cnt:ephObjCnt
-                           longitude:topoLon latitude:topoLat elevation:topoElev
-                         topocentric:topocentricSearch];
+                           longitude:topoLon latitude:topoLat elevation:topoElev topocentric:topocentricSearch
+                        heliocentric:heliocentricSearch equatorial:equatorialSearch];
         //for (i=0; i<O_ARRAYSIZE; i++)
         //    eph[i] = ephObject[i];
     }
@@ -333,8 +341,8 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
         tjd = [ephemeris julianDayForDate:date bc:NO];
         objects = [ephemeris objectsAtJD:tjd flags:ephFlags
                                  objects:ephObjIx cnt:ephObjCnt
-                               longitude:topoLon latitude:topoLat elevation:topoElev
-                             topocentric:topocentricSearch];
+                               longitude:topoLon latitude:topoLat elevation:topoElev topocentric:topocentricSearch
+                            heliocentric:heliocentricSearch equatorial:equatorialSearch];
         /* add section date only, if retro changes or delta >= 360deg */
         if ( !secCnt || min >= minCycle ||			// delta >= full cycle
              retro != ((objects[obj1].vLon < 0.0) ? YES : NO) )	// retro changes
@@ -775,8 +783,8 @@ NSLog(@"Search dict = %@", dict);
 
         objects = [ephemeris objectsAtJD:[ephemeris julianDayForDate:date bc:NO] flags:ephFlags
                                  objects:ephObjIx cnt:ephObjCnt
-                               longitude:topoLon latitude:topoLat elevation:topoElev
-                             topocentric:topocentricSearch];
+                               longitude:topoLon latitude:topoLat elevation:topoElev topocentric:topocentricSearch
+                            heliocentric:heliocentricSearch equatorial:equatorialSearch];
 
         [date retain];
         if (searchAngles)
@@ -808,7 +816,7 @@ NSLog(@"Search dict = %@", dict);
                         delta1 = Abs(prSign);           // delta to target
                         dSec = - ((minutes*60) - (minutes*60 * delta1 / delta));
                         if (Abs(dSec/60) > minutes)
-                        {   NSLog(@"searchAspect, error in calculation: dSec = %f", dSec);
+                        {   NSLog(@"searchAspect, error in calculation: dSec = %d", dSec);
                             dSec = 0.0;
                         }
                         date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
