@@ -1,32 +1,32 @@
 /* EventManager.h
  *
- * Copyright (C) 2003-2010 by vhf interservice GmbH
+ * Copyright (C) 2003-2010 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2003-06-22
  * modified: 2010-01-16 (allow moving/resizing in grid)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
-#ifndef VHF_H_EVENTMANAGER
-#define VHF_H_EVENTMANAGER
+#ifndef CEN_H_EVENTMANAGER
+#define CEN_H_EVENTMANAGER
 
 #include <AppKit/AppKit.h>
 
@@ -88,4 +88,4 @@
 
 @end
 
-#endif	// VHF_H_EVENTMANAGER
+#endif	// CEN_H_EVENTMANAGER
