@@ -2,29 +2,29 @@
  * Commander of the map
  * This class is associated to a view containing the map.
  *
- * Copyright (C) 2003-2006 by vhf interservice GmbH
+ * Copyright (C) 2003-2006 by Cenon GmbH
  * Author:   Georg Fleischmann, Ilonka Fleischmann
  *
  * created:  2003-07-14
  * modified: 2006-05-31 (house lines)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
 #include <Foundation/Foundation.h>
@@ -187,20 +187,20 @@ NSPoint pointOnLineDistanceFromEnd(float dist, NSPoint p0, NSPoint p1)
  * we draw lines through locations where the axes are on a planet
  */
 - (VGroup*)mapChartWithDate:(NSCalendarDate*)utc title:(NSString*)title inBounds:(NSRect)viewBounds
-{   VGroup		*group = [VGroup group];
-    VGroup		*groupACText = [VGroup group], *groupMCText = [VGroup group];
-    VLine		*line;
-    VArc		*arc;
-    int			i, j;
-    Ephemeris		*ephemeris = [Astro_Principal ephemeris];
-    NSDictionary	*degreeDict = [ephemeris objectDictAtUTC:utc];
-    NSArray		*planets = Prefs_Objects;
-    NSColor		*color;
-    float		lineWidth = 1.0;
-    BOOL		isACLine, wasACLine = NO;
-    double		jd = vhfJulianDay(utc);	// julian day (reference -4712)
-    NSString		*astroFontName = (![(NSString*)Prefs_AstroFont length]) ? @"vhfAstro" : Prefs_AstroFont;
-    NSFont		*symbolFont14 = [NSFont fontWithName:astroFontName size:14];
+{   VGroup          *group = [VGroup group];
+    VGroup          *groupACText = [VGroup group], *groupMCText = [VGroup group];
+    VLine           *line;
+    VArc            *arc;
+    int             i, j;
+    Ephemeris       *ephemeris = [Astro_Principal ephemeris];
+    NSDictionary    *degreeDict = [ephemeris objectDictAtUTC:utc];
+    NSArray         *planets = Prefs_Objects;
+    NSColor         *color;
+    float           lineWidth = 1.0;
+    BOOL            isACLine, wasACLine = NO;
+    double          jd = vhfJulianDay(utc);	// julian day (reference -4712)
+    NSString        *astroFontName = (![(NSString*)Prefs_AstroFont length]) ? @"vhfAstro" : Prefs_AstroFont;
+    NSFont          *symbolFont14 = [NSFont fontWithName:astroFontName size:14];
 
     [dateAxes release];
     dateAxes = [utc retain];
@@ -435,19 +435,19 @@ NSLog(@"1: lat=%f l1=%f -> p={%.2f %.2f}", lat, lon, p.x, p.y);
  */
 - (VGroup*)mapHousesAtDate:(NSCalendarDate*)utc lat:(float)refLat lon:(float)refLon
                      title:(NSString*)title inBounds:(NSRect)viewBounds
-{   VGroup		*group = [VGroup group];
-    VGroup		*groupACText = [VGroup group], *groupMCText = [VGroup group];
-    VLine		*line;
-    VArc		*arc;
-    int			i, j, houseCnt = 12, n;
-    float		lineWidth = 1.0;
-    double		jd = vhfJulianDay(utc);	// julian day (reference -4712)
-    NSString		*astroFontName = (![(NSString*)Prefs_AstroFont length]) ? @"vhfAstro" : Prefs_AstroFont;
-    NSFont		*symbolFont14 = [NSFont fontWithName:astroFontName size:14];
-    NSFont		*systemFont14 = [NSFont systemFontOfSize:14];
+{   VGroup              *group = [VGroup group];
+    VGroup              *groupACText = [VGroup group], *groupMCText = [VGroup group];
+    VLine               *line;
+    VArc                *arc;
+    int                 i, j, houseCnt = 12, n;
+    float               lineWidth = 1.0;
+    double              jd = vhfJulianDay(utc);	// julian day (reference -4712)
+    NSString            *astroFontName = (![(NSString*)Prefs_AstroFont length]) ? @"vhfAstro" : Prefs_AstroFont;
+    NSFont              *symbolFont14 = [NSFont fontWithName:astroFontName size:14];
+    NSFont              *systemFont14 = [NSFont systemFontOfSize:14];
     TopocentricCycle	*topo = [TopocentricCycle topocentricCycleAtDate:utc latitude:refLat longitude:refLon];
-    double		*houses = [topo houses:houseCnt];
-    NSArray		*houseColors;
+    double              *houses = [topo houses:houseCnt];
+    NSArray             *houseColors;
 
     houseColors = [NSArray arrayWithObjects:
             [NSColor colorWithCalibratedHue:0.000 saturation:1.0 brightness:1.0 alpha:1.0], // aries
@@ -726,24 +726,24 @@ NSLog(@"1: lat=%f l1=%f -> p={%.2f %.2f}", lat, lon, p.x, p.y);
 - (VGroup*)mapTimeTrackFromDate:(NSCalendarDate*)dateFr toDate:(NSCalendarDate*)dateTo
                      forObjects:(NSArray*)objects earthRevolution:(BOOL)earthRev
                           title:(NSString*)title inBounds:(NSRect)viewBounds
-{   VGroup		*group = [VGroup group];
-    Ephemeris		*ephemeris = [[AstroPrincipal instance] ephemeris];
+{   VGroup              *group = [VGroup group];
+    Ephemeris           *ephemeris = [[AstroPrincipal instance] ephemeris];
     //EphemerisSearch	*ephemerisSearch = nil;
-    //NSArray		*searchArray = nil;
-    VPolyLine		*polyLine[[objects count]];
-    int			objectIx[[objects count]], i, cnt = 0, objIx;
-    NSTimeInterval	timeRange = [dateTo timeIntervalSinceDate:dateFr];
-    EphemerisFlags	ephFlags = EPHFLAG_LON + EPHFLAG_DEC + EPHFLAG_LOC;	// what to calculate
-    EphemerisObjects	ephObjIx[[objects count]];	// objects to calculate
-    int			ephObjCnt = 0;			// number of objects in array
-    int			interval = (int)STARDAY_SEC;	// interval in [min]
-    NSCalendarDate	*date = dateFr;
-    //BOOL		topoFlag = Prefs_Topocentric;
-    float		lat = 0.0, lon = 0.0;
-    int			elev = 0;
-    NSPoint		p, pPrev[[objects count]];
-    float		lineWidth = 1.0;
-    NSFont		*font = [NSFont fontWithName:Prefs_AstroFont size:20.0];
+    //NSArray           *searchArray = nil;
+    VPolyLine           *polyLine[[objects count]];
+    int                 objectIx[[objects count]], i, cnt = 0, objIx;
+    NSTimeInterval      timeRange = [dateTo timeIntervalSinceDate:dateFr];
+    EphemerisFlags      ephFlags = EPHFLAG_LON + EPHFLAG_DEC + EPHFLAG_LOC;	// what to calculate
+    EphemerisObjects    ephObjIx[[objects count]];	// objects to calculate
+    int                 ephObjCnt = 0;			// number of objects in array
+    int                 interval = (int)STARDAY_SEC;	// interval in [min]
+    NSCalendarDate      *date = dateFr;
+    //BOOL              topoFlag = Prefs_Topocentric;
+    float               lat = 0.0, lon = 0.0;
+    int                 elev = 0;
+    NSPoint             p, pPrev[[objects count]];
+    float               lineWidth = 1.0;
+    NSFont              *font = [NSFont fontWithName:Prefs_AstroFont size:20.0];
 
     if (!ephemeris)
         return nil;
@@ -788,7 +788,8 @@ NSLog(@"1: lat=%f l1=%f -> p={%.2f %.2f}", lat, lon, p.x, p.y);
         lat = 0.0; lon = 0.0; elev = 0;
         ephObjects = [ephemeris objectsAtJD:tjd flags:ephFlags
                                     objects:ephObjIx cnt:ephObjCnt
-                                  longitude:lon latitude:lat elevation:elev topocentric:NO];
+                                  longitude:lon latitude:lat elevation:elev topocentric:NO
+                               heliocentric:NO equatorial:NO];
 
         //[progressTarget performSelector:progressAction
         //                     withObject:[NSNumber numberWithFloat:(float)loop++/(float)loopCnt]];
