@@ -1,34 +1,35 @@
 /* Ephemeris.h
  * front end object for the Swiss Ephemeris
  *
- * Copyright (C) 1999-2011 by Georg Fleischmann
+ * Copyright (C) 1999-2015 by Georg Fleischmann
  * Author:   Georg Fleischmann
  *
  * created:  1999-11-30
- * modified: 2011-04-24 (-objectSymbols)
+ * modified: 2014-11-21 (calcHelio, heliocentric added)
+ *           2011-04-24 (-objectSymbols)
  *           2008-08-23 (EPH_SYMBOLS added)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
-#ifndef VHF_H_EPHEMERIS
-#define VHF_H_EPHEMERIS
+#ifndef CEN_H_EPHEMERIS
+#define CEN_H_EPHEMERIS
 
 #include	"swephexp.h"
 
@@ -56,10 +57,10 @@ typedef enum
     EPH_URANUS      = SE_URANUS,
     EPH_NEPTUNE     = SE_NEPTUNE,
     EPH_PLUTO       = SE_PLUTO,
-    EPH_NODE        = SE_MEAN_NODE,
-    EPH_TRUENODE    = SE_TRUE_NODE,
-    EPH_APOGEE      = SE_MEAN_APOG,
-    EPH_TRUEAPOGEE  = SE_OSCU_APOG,
+    EPH_NODE        = SE_MEAN_NODE, // 10
+    EPH_TRUENODE    = SE_TRUE_NODE, // 11
+    EPH_APOGEE      = SE_MEAN_APOG, // 12
+    EPH_TRUEAPOGEE  = SE_OSCU_APOG, // 13
     EPH_CHIRON      = SE_CHIRON,
     EPH_PHOLUS      = SE_PHOLUS,
     EPH_CERES       = SE_CERES,
@@ -71,6 +72,7 @@ typedef enum
     EPH_MC          = 22,
     MC              = 22,            // deprecated
     EPH_COUNT       = 23,
+    EPH_ECL         = 100,
     EPH_NONE        = -1 // no object
 } EphemerisObjects;
 
@@ -117,33 +119,33 @@ typedef enum
  */
 typedef struct
 {
-    double	lon;		// the zodiac position (ecliptical longitude)
-    double	lat;		// Ecliptic latitude
-    double	vLon;		// speed in longitude (deg/day), negative = retrograde
-    double	vLat;		// speed in latitude  (deg/day), negative = retrograde
+    double	lon;            // the zodiac position (ecliptical longitude)
+    double	lat;            // Ecliptic latitude
+    double	vLon;           // speed in longitude (deg/day), negative = retrograde
+    double	vLat;           // speed in latitude  (deg/day), negative = retrograde
 
-    double	rec;		// equatorial rectascension
-    double	dec;		// equatorial declination (earth latitude)
-    double	vRec;		// speed in rectascension
-    double	vDec;		// speed in declination
+    double	rec;            // equatorial rectascension
+    double	dec;            // equatorial declination (earth latitude)
+    double	vRec;           // speed in rectascension
+    double	vDec;           // speed in declination
 
-    double	nodeLon;	// ecliptical longitude of ascending node
-    double	nodeLat;	// ecliptical latitude  of ascending node
-    double	nodeVLon;	// speed of ascending node in longitude
-    double	nodeVLat;	// speed of ascending node in latitude
-    double	dscNodeLon;	// ecliptical longitude of descending node
-    double	dscNodeLat;	// ecliptical latitude  of descending node
-    double	dscNodeVLon;	// speed of descending node in longitude
-    double	dscNodeVLat;	// speed of descending node in latitude
+    double	nodeLon;        // ecliptical longitude of ascending node
+    double	nodeLat;        // ecliptical latitude  of ascending node
+    double	nodeVLon;       // speed of ascending node in longitude
+    double	nodeVLat;       // speed of ascending node in latitude
+    double	dscNodeLon;     // ecliptical longitude of descending node
+    double	dscNodeLat;     // ecliptical latitude  of descending node
+    double	dscNodeVLon;    // speed of descending node in longitude
+    double	dscNodeVLat;    // speed of descending node in latitude
 
-    double	perihelionLon;	// ecliptical longitude of perihelion (closest to Sun)
-    double	perihelionLat;	// ecliptical latitude  of perihelion
-    double	perihelionVLon;	// speed of perihelion in longitude
-    double	perihelionVLat;	// speed of perihelion in latitude
-    double	aphelionLon;	// ecliptical longitude of aphelion (farthest to Sun)
-    double	aphelionLat;	// ecliptical latitude  of aphelion
-    double	aphelionVLon;	// speed of aphelion in longitude
-    double	aphelionVLat;	// speed of aphelion in latitude
+    double	perihelionLon;  // ecliptical longitude of perihelion (closest to Sun)
+    double	perihelionLat;  // ecliptical latitude  of perihelion
+    double	perihelionVLon; // speed of perihelion in longitude
+    double	perihelionVLat; // speed of perihelion in latitude
+    double	aphelionLon;    // ecliptical longitude of aphelion (farthest to Sun)
+    double	aphelionLat;    // ecliptical latitude  of aphelion
+    double	aphelionVLon;   // speed of aphelion in longitude
+    double	aphelionVLat;   // speed of aphelion in latitude
 
     //double	perigeeLon;	// ecliptical longitude of pregigee (closest to Earth)
     //double	perigeeLat;	// ecliptical latitude  of pregigee
@@ -157,13 +159,13 @@ typedef struct
 
 @interface Ephemeris:NSObject
 {
-    NSArray	*objectNames;
-    EphObject	objects[30];
-    BOOL	calculateMeanNodes;
+    NSArray     *objectNames;
+    EphObject   objects[30];
+    BOOL        calculateMeanNodes;
 
-    double	calcJD;		// last calculation date
-    BOOL	calcTopo;
-    float	calcLat, calcLon, calcElev;
+    double      calcJD;		// last calculation date
+    BOOL        calcTopo, calcHelio, calcEqua;
+    float       calcLat, calcLon, calcElev;
 }
 
 - (id)init;
@@ -181,30 +183,43 @@ typedef struct
 - (double)julianDayForYear:(int)year month:(int)month day:(int)day
                       hour:(int)hour minute:(int)minute second:(int)second bc:(BOOL)bcFlag;
 
-/* NSCalendar date methods */
+/* NSCalendarDate methods */
 - (EphObject*)objectsAtUTC:(NSCalendarDate*)utc;
 - (EphObject*)objectsAtUTC:(NSCalendarDate*)utc lat:(float)lat  lon:(float)lon;
 - (EphObject*)objectsAtUTC:(NSCalendarDate*)utc lat:(double)lat lon:(double)lon
-                      elev:(double)alt topocentric:(BOOL)topocentric;
+                      elev:(double)alt topocentric:(BOOL)topocentric
+              heliocentric:(BOOL)heliocentric
+                equatorial:(BOOL)equatorial;
 - (BOOL)calculatedAtDate:(NSCalendarDate*)date tolerance:(int)tol
-                     lat:(float)lat lon:(float)lon elev:(float)elev topocentric:(BOOL)topo;
+                     lat:(float)lat lon:(float)lon elev:(float)elev topocentric:(BOOL)topo
+            heliocentric:(BOOL)helio
+              equatorial:(BOOL)equatorial;
+
 /* year, month, day, ... methods */
 - (EphObject*)objectsAtYear:(int)year month:(int)month day:(int)day
                        hour:(int)hour minute:(int)minute second:(int)second
-                  longitude:(double)lon latitude:(double)lat elevation:(double)alt;
+                  longitude:(double)lon latitude:(double)lat elevation:(double)alt
+                topocentric:(BOOL)topoFlag    /* truePos:(BOOL)truePosFlag */
+               heliocentric:(BOOL)helioFlag
+                 equatorial:(BOOL)equatorial;
+
 /* basic method using julian day (universal time, reference = -4712)
  * also uses external flag: calculateMeanNodes
  */
 - (EphObject*)objectsAtJD:(double)tjd flags:(EphemerisFlags)ephFlags
                   objects:(EphemerisObjects*)objs cnt:(int)objCnt
                 longitude:(double)lon latitude:(double)lat elevation:(double)alt
-              topocentric:(BOOL)topoFlag;
+              topocentric:(BOOL)topoFlag    /* truePos:(BOOL)truePosFlag */
+             heliocentric:(BOOL)helioFlag
+               equatorial:(BOOL)equatorial;
 
 /* dictionary frontend methods */
 - (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc;
-- (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc lat:(float)lat lon:(float)lon;
+- (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc lat:(float)lat  lon:(float)lon;
 - (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc lat:(double)lat lon:(double)lon
-                                   elev:(double)alt topocentric:(BOOL)topocentric;
+                                   elev:(double)alt topocentric:(BOOL)topocentric
+                           heliocentric:(BOOL)heliocentric
+                             equatorial:(BOOL)equatorial;
 - (NSMutableDictionary*)currentObjectDict;
 - (NSMutableDictionary*)currentSpeedLonDict;	// V lon
 - (NSMutableDictionary*)currentNodeDict;
@@ -216,4 +231,4 @@ typedef struct
 
 @end
 
-#endif	// VHF_H_EPHEMERIS
+#endif	// CEN_H_EPHEMERIS
