@@ -1,30 +1,33 @@
 /* Ephemeris.m
  * front end object for the Swiss Ephemeris
  *
- * Copyright (C) 1999-2011 by vhf interservice GmbH
+ * Copyright (C) 1999-2015 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2001-09-02
- * modified: 2011-04-24 (-objectSymbols)
+ * modified: 2015-01-26 (equatorial)
+ *           2014-11-21 (calcHelio, heliocentric added)
+ *           2014-01-04 (clean up)
+ *           2011-04-24 (-objectSymbols)
  *           2008-08-23 (-indexForObjectSymbol: added)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
 #include <Foundation/Foundation.h>
@@ -69,8 +72,10 @@ static NSArray *objectSymbols = nil;
 {
     if (path)
     {
-        ephepath = calloc([path cStringLength]+1, sizeof(char));
-        [path getCString:ephepath];
+        //ephepath = calloc([path cStringLength]+1, sizeof(char));
+        //[path getCString:ephepath];
+        ephepath = calloc([path length]+1, sizeof(char));
+        [path getCString:ephepath maxLength:[path length]+1 encoding:NSUTF8StringEncoding];
         swe_set_ephe_path(ephepath);
     }
 }
@@ -133,6 +138,8 @@ static NSArray *objectSymbols = nil;
 }
 - (EphObject*)objectsAtUTC:(NSCalendarDate*)utc lat:(double)lat lon:(double)lon
                       elev:(double)alt topocentric:(BOOL)topocentric
+              heliocentric:(BOOL)heliocentric
+                equatorial:(BOOL)equatorial
 {   NSCalendarDate	*st = sideralTime(utc, lon);
     EphObject		*objs;
 
@@ -140,7 +147,9 @@ static NSArray *objectSymbols = nil;
         lon = -360.0;
     objs = [self objectsAtYear:[utc yearOfCommonEra]  month:[utc monthOfYear]     day:[utc dayOfMonth]
                           hour:[utc hourOfDay]       minute:[utc minuteOfHour] second:[utc secondOfMinute]
-                     longitude:lon latitude:lat elevation:alt];
+                     longitude:lon latitude:lat elevation:alt
+                   topocentric:topocentric /*truePos:NO */
+                  heliocentric:heliocentric equatorial:equatorial];
 
     /* add ac, mc */
     objs[O_AC].lon = ac(st, lat);
@@ -161,35 +170,31 @@ static NSArray *objectSymbols = nil;
 
     return [self objectsAtYear:[utc yearOfCommonEra]  month:[utc monthOfYear]     day:[utc dayOfMonth]
                           hour:[utc hourOfDay]       minute:[utc minuteOfHour] second:[utc secondOfMinute]
-                     longitude:-360.0 latitude:-360.0 elevation:0.0];
+                     longitude:-360.0 latitude:-360.0 elevation:0.0
+                   topocentric:NO /*truePos:NO */
+                  heliocentric:NO equatorial:NO];
 }
 
 /* created:  1999
- * modified: 2006-02-02 (Asteroids added)
+ * modified: 2014-11-21 (helioFlag added)
+ *           2006-02-02 (Asteroids added)
  *
  * return ephemeris, projection on earth
- * the method returns a dictionary containing the following values for each planet:
- * angle, declination, direction
  *
  * Parameters:
  *  longitude:	E = +  W = -
  *  latitude:	N = +  S = -
  *  elevation:	meters above sea level
- *
- * dictionary =
- * {
- *     "gmt" = NSCalendarDate;
- *     "Moon" = (angle, declination, DIR_NORMAL);
- *     "Sun" = (12.2, 0.0, DIR_NORMAL);
- *     ...
- * }
  */
 - (EphObject*)objectsAtYear:(int)year  month:(int)month     day:(int)day
                        hour:(int)hour minute:(int)minute second:(int)second
                   longitude:(double)lon latitude:(double)lat elevation:(double)alt
+                topocentric:(BOOL)topoCen    /* truepos:(BOOL)truePosFlag */
+               heliocentric:(BOOL)helioCen
+                 equatorial:(BOOL)equatorial    // equatorial instead of ecliptical
 {   int		p;
     double	tjd, x2[6], h;
-    long	iflag = SEFLG_SPEED, iflgret, topoFlag = 0;
+    long	iflag = SEFLG_SPEED, iflgret, topoFlag = 0, helioFlag = 0;
     char	serr[AS_MAXCH];
 
     /* we have day, month and year and convert to Julian day number */
@@ -200,12 +205,20 @@ static NSArray *objectSymbols = nil;
     /* compute Ephemeris time from Universal time by adding delta_t */
     //te = tjd + swe_deltat(tjd);
 
+    /* TODO: [self objectsAtJD:tjd flags:(EphemerisFlags)ephFlags
+              objects:(EphemerisObjects*)objs cnt:(int)objCnt
+            longitude:lon latitude:lat elevation:alt topocentric:topoCen];
+         heliocentric:helioCen*/
+
     /* topocentric positions (observed from location on earth) */
-    if (lon >= -180.0 && lat >= -90.0)
-    {
-        swe_set_topo(lon, lat, alt);
+    if ( topoCen && lon >= -180.0 && lat >= -90.0 )
+    {   swe_set_topo(lon, lat, alt);
         topoFlag = SEFLG_TOPOCTR;
     }
+    // TODO: SEFLG_TRUEPOS adds the true position of planet (opposed to visible position in sky)
+    /* heliocentric positions (instead of geocentric / apparent) */
+    if ( helioCen )
+        helioFlag = SEFLG_HELCTR;
 
     /* a loop over all planets */
     for (p = SE_SUN; p <= SE_VESTA; p++)
@@ -221,7 +234,15 @@ static NSArray *objectSymbols = nil;
          * x[4] = speed in latitude (deg/day), negative = retrograde
          * x[5] = speed in distance (AU/day)
          */
-        iflag = SEFLG_SPEED | topoFlag;
+        iflag = SEFLG_SPEED;
+        if ( equatorial )
+            iflag |= SEFLG_EQUATORIAL;  // (heliocentric) equatorial coordinates
+        if ( helioFlag                  // Moon, Sun, Moon-Nodes/Apogee stay geo- or topocentric
+             && (   p != SE_MOON      && p != SE_SUN
+                 && p != SE_MEAN_NODE && p != SE_TRUE_NODE && p != SE_MEAN_APOG && p != SE_OSCU_APOG) )
+            iflag |= helioFlag | SEFLG_NOGDEFL | SEFLG_NOABERR;
+        else                            // helio has priority for planets (but not Moon and Sun)
+            iflag |= topoFlag;
         if ((iflgret = swe_calc_ut(tjd, p, iflag, x2, serr)) < 0)
             NSLog(@"error: %s\n", serr);
         else if (iflgret != iflag)
@@ -237,7 +258,7 @@ static NSArray *objectSymbols = nil;
         if ((iflgret = swe_calc_ut(tjd, p, iflag | SEFLG_EQUATORIAL, x2, serr)) < 0)
             NSLog(@"error: %s (equatorial).\n", serr);
         else if (iflgret != (iflag|SEFLG_EQUATORIAL))
-            NSLog(@"warning: iflgret (%f) != iflag (%f) (equatorial).\n", iflgret, iflag|SEFLG_EQUATORIAL);
+            NSLog(@"warning: iflgret (%ld) != iflag (%ld) (equatorial).\n", iflgret, iflag|SEFLG_EQUATORIAL);
         objects[p].rec  = x2[0];	// rectascension
         objects[p].dec  = x2[1];	// declination
         //objects[p].dist = x2[2];	// distance in AU
@@ -261,7 +282,9 @@ static NSArray *objectSymbols = nil;
         if (p >= SE_MEAN_NODE && p <= SE_OSCU_APOG)	// skip Moon node/apogee
             continue;
 
-        iflag = SEFLG_SPEED /*| topoFlag*/;
+        iflag = SEFLG_SPEED /*| topoFlag*/ | helioFlag;
+        if ( equatorial )
+            iflag |= SEFLG_EQUATORIAL;  // (heliocentric) equatorial coordinates
         {   double	xnasc[6], xndsc[6], xperi[6], xaphe[6];
             int		nodeBit = (calculateMeanNodes) ? SE_NODBIT_MEAN : SE_NODBIT_OSCU;
 
@@ -386,7 +409,8 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
 
 /* Basic ephemeris calculation
  * created:  2006-02-02 (replacement of other method)
- * modified: 2006-02-02
+ * modified: 2015-01-26 (equatorial flag)
+ *           2014-11-21 (helioFlag added)
  *
  * Parameters:
  *  mjd:         modified julian day
@@ -403,7 +427,9 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
 - (EphObject*)objectsAtJD:(double)tjd flags:(EphemerisFlags)ephFlags
                   objects:(EphemerisObjects*)objs cnt:(int)objCnt
                 longitude:(double)lon latitude:(double)lat elevation:(double)alt
-              topocentric:(BOOL)topoFlag
+              topocentric:(BOOL)topoFlag    /* truePos:(BOOL)truePosFlag */
+             heliocentric:(BOOL)helioFlag
+               equatorial:(BOOL)equatorialFlag  // equatorial instead of ecliptical
 {   int		i, p;
     double	x2[6];
     long	iflag = SEFLG_SPEED, iflgret;
@@ -419,6 +445,8 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
     else
         topoFlag = NO;
 
+    // SEFLG_TRUEPOS adds the true position of planet (opposed to visible position in sky)
+
     /* a loop over all planets */
     for (i = 0; i < objCnt; i++)
     {
@@ -435,7 +463,15 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
          * x[5] = speed in distance (AU/day)
          */
 
-        iflag = SEFLG_SPEED | ((topoFlag) ? SEFLG_TOPOCTR : 0);
+        iflag = SEFLG_SPEED /*| ((topoFlag) ? SEFLG_TOPOCTR : 0)*/;
+        if ( equatorialFlag )
+            iflag |= SEFLG_EQUATORIAL;  // (heliocentric) equatorial coordinates
+        if ( helioFlag                  // Moon, Sun, Moon-Nodes/Apogee stay geo- or topocentric
+            && (   p != SE_MOON      && p != SE_SUN
+                && p != SE_MEAN_NODE && p != SE_TRUE_NODE && p != SE_MEAN_APOG && p != SE_OSCU_APOG) )
+            iflag |= SEFLG_HELCTR | SEFLG_NOGDEFL | SEFLG_NOABERR;
+        else if (topoFlag)              // helio has priority for planets (but not Moon and Sun)
+            iflag |= SEFLG_TOPOCTR;
 
         /* ecliptical */
         if ( ephFlags & (EPHFLAG_LON + EPHFLAG_LAT))
@@ -460,7 +496,7 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
             if ((iflgret = swe_calc_ut(tjd, p, iflag | SEFLG_EQUATORIAL, x2, serr)) < 0)
                 NSLog(@"error: %s (equatorial).\n", serr);
             else if (iflgret != (iflag|SEFLG_EQUATORIAL))
-                NSLog(@"warning: iflgret (%f) != iflag (%f) (equatorial).\n", iflgret, iflag|SEFLG_EQUATORIAL);
+                NSLog(@"warning: iflgret (%ld) != iflag (%ld) (equatorial).\n", iflgret, iflag|SEFLG_EQUATORIAL);
             objects[p].rec  = x2[0];	// rectascension
             objects[p].dec  = x2[1];	// declination
             //objects[p].dist = x2[2];	// distance in AU
@@ -489,7 +525,9 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
             if (p >= SE_MEAN_NODE && p <= SE_OSCU_APOG)	// skip Moon node/apogee
                 continue;
 
-            iflag = SEFLG_SPEED /*| ((topoFlag) ? SEFLG_TOPOCTR : 0)*/;
+            iflag = SEFLG_SPEED /*| ((topoFlag) ? SEFLG_TOPOCTR : 0)*/ | ((helioFlag) ? SEFLG_HELCTR : 0);
+            if ( equatorialFlag )
+                iflag |= SEFLG_EQUATORIAL;  // (heliocentric) equatorial coordinates
 
             if ((iflgret = swe_nod_aps_ut(tjd, p, iflag, nodeBit, xnasc, xndsc, xperi, xaphe, serr)) < 0)
                 NSLog(@"error: %s (Nodes)\n", serr);
@@ -613,6 +651,26 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
     return objects;
 }
 
+/* created:  1999
+ * modified: 2006-02-02 (Asteroids added)
+ *
+ * return ephemeris, projection on earth
+ * the method returns a dictionary containing the following values for each planet:
+ * angle, declination, direction
+ *
+ * Parameters:
+ *  longitude:	E = +  W = -
+ *  latitude:	N = +  S = -
+ *  elevation:	meters above sea level
+ *
+ * dictionary =
+ * {
+ *     "gmt" = NSCalendarDate;
+ *     "Moon" = (angle, declination, DIR_NORMAL);
+ *     "Sun" = (12.2, 0.0, DIR_NORMAL);
+ *     ...
+ * }
+ */
 - (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc lat:(float)lat lon:(float)lon
 {   NSCalendarDate      *st = sideralTime(utc, lon);
     NSMutableDictionary	*degreeDict = [self objectDictAtUTC:utc];
@@ -622,14 +680,17 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
     return degreeDict;
 }
 
-- (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc lat:(double)lat lon:(double)lon
-                                   elev:(double)alt topocentric:(BOOL)topocentric;
+- (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc
+                                    lat:(double)lat lon:(double)lon elev:(double)alt topocentric:(BOOL)topocentric
+                           heliocentric:(BOOL)heliocentric
+                             equatorial:(BOOL)equatorial
 {   NSMutableDictionary *degreeDict = [NSMutableDictionary dictionary];
     int                 p;
     EphObject           *objs;
     //NSCalendarDate    *st = sideralTime(utc, lon);
 
-    objs = [self objectsAtUTC:utc lat:lat lon:lon elev:alt topocentric:topocentric];
+    objs = [self objectsAtUTC:utc lat:lat lon:lon elev:alt topocentric:topocentric
+                 heliocentric:heliocentric equatorial:equatorial];
 
     for (p = SE_SUN; p <= SE_VESTA; p++)
         [degreeDict setObject:[NSNumber numberWithDouble:objs[p].lon]
@@ -639,42 +700,48 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
     //[degreeDict setObject:[NSNumber numberWithDouble:ac(st, lat)] forKey:@"AC"];
     //[degreeDict setObject:[NSNumber numberWithDouble:mc(st)] forKey:@"MC"];
 
-    calcJD   = [self julianDayForDate:utc bc:NO];
-    calcLat  = lat;
-    calcLon  = lon;
-    calcElev = alt;
-    calcTopo = topocentric;
+    calcJD    = [self julianDayForDate:utc bc:NO];
+    calcLat   = lat;
+    calcLon   = lon;
+    calcElev  = alt;
+    calcTopo  = topocentric;
+    calcHelio = heliocentric;
+    calcEqua  = equatorial;
 
     return degreeDict;
 }
 
 /* is dictionary already calculated ?
- * created: 2006-08-18
+ * created:  2006-08-18
+ * modified: 2014-11-21 (helio)
  */
 - (BOOL)calculatedAtDate:(NSCalendarDate*)date tolerance:(int)tol
                      lat:(float)lat lon:(float)lon elev:(float)elev topocentric:(BOOL)topo
+            heliocentric:(BOOL)helio equatorial:(BOOL)equatorial
 {
-    if ( ( (topo || calcTopo) && calcTopo == topo
+    if ( ( (topo || calcTopo) && calcTopo == topo && calcHelio == helio && calcEqua == equatorial
            && Diff(elev, calcElev) < TOLERANCE
-           && Diff(lat, calcLat) < TOLERANCE && Diff(lon, calcLon) < TOLERANCE )
+           && Diff(lat,  calcLat)  < TOLERANCE && Diff(lon, calcLon) < TOLERANCE )
          && Diff([self julianDayForDate:date bc:NO], calcJD) <= (double)tol/(24.0*60.0) )
         return YES;
     return NO;
 }
 
 - (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc
-{   NSMutableDictionary		*degreeDict = [NSMutableDictionary dictionary];
-    int				p;
-    EphObject			*objs = [self objectsAtUTC:utc];
+{   NSMutableDictionary *degreeDict = [NSMutableDictionary dictionary];
+    int                 p;
+    EphObject           *objs = [self objectsAtUTC:utc];
 
     for (p = SE_SUN; p <= SE_VESTA; p++)
         [degreeDict setObject:[NSNumber numberWithDouble:objs[p].lon]
                        forKey:[objectNames objectAtIndex:p]];
 
-    calcJD   = [self julianDayForDate:utc bc:NO];
-    calcLat  = calcLon = 0.0;
-    calcElev = 0.0;
-    calcTopo = NO;
+    calcJD    = [self julianDayForDate:utc bc:NO];
+    calcLat   = calcLon = 0.0;
+    calcElev  = 0.0;
+    calcTopo  = NO;
+    calcHelio = NO;
+    calcEqua  = NO;
 
     return degreeDict;
 }
@@ -682,8 +749,8 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
 /* get current objects
  */
 - (NSMutableDictionary*)currentObjectDict
-{   NSMutableDictionary		*degreeDict = [NSMutableDictionary dictionary];
-    int				p;
+{   NSMutableDictionary *degreeDict = [NSMutableDictionary dictionary];
+    int                 p;
 
     for (p = SE_SUN; p <= SE_VESTA; p++)
         [degreeDict setObject:[NSNumber numberWithDouble:objects[p].lon]
@@ -693,8 +760,8 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
 /* get speed from current objects
  */
 - (NSMutableDictionary*)currentSpeedLonDict
-{   NSMutableDictionary		*speedDict = [NSMutableDictionary dictionary];
-    int				p;
+{   NSMutableDictionary *speedDict = [NSMutableDictionary dictionary];
+    int                 p;
 
     for (p = SE_SUN; p <= SE_VESTA; p++)
         [speedDict setObject:[NSNumber numberWithDouble:objects[p].vLon]
