@@ -1,33 +1,33 @@
 /* TopocentricCycle.h
  * Topocentric houses and related functions
  *
- * Copyright (C) 1999-2004 by vhf interservice GmbH
+ * Copyright (C) 1999-2004 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2003-08-11
  * modified: 2004-07-13
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
-#ifndef VHF_H_TOPOCENTRIC
-#define VHF_H_TOPOCENTRIC
+#ifndef CEN_H_TOPOCENTRIC
+#define CEN_H_TOPOCENTRIC
 
 typedef struct _TopocentricSettings
 {
@@ -48,13 +48,14 @@ typedef struct _TopocentricSettings
 @interface TopocentricCycle:NSObject
 {
     TOPO	topo;
+    BOOL	isDirty;	// we need a fresh calculation
 }
 
 + (TopocentricCycle*)topocentricCycleAtDate:(NSCalendarDate*)utc latitude:(float)lat longitude:(float)lon;
 - (id)initWithDate:(NSCalendarDate*)utc latitude:(float)lat longitude:(float)lon;
 - (void)setDate:(NSCalendarDate*)utc latitude:(float)lat longitude:(float)lon;
 - (void)setDate:(int)yymmdd time:(int)hhmm latitude:(float)lat longitude:(float)lon;
-- (void)setLatitude:(float)lat longitude:(float)lon;	// only updates lat/lon
+- (void)setLatitude:(float)lat longitude:(float)lon;	// updates lat/lon only
 
 - (double)ac;
 - (double)mc;
@@ -67,4 +68,4 @@ typedef struct _TopocentricSettings
 
 @end
 
-#endif // VHF_H_TOPOCENTRIC
+#endif // CEN_H_TOPOCENTRIC
