@@ -1,37 +1,39 @@
 /* astroCommon.h
  * Common astronomical functions
  *
- * Copyright (C) 1998-2012 by vhf interservice GmbH
+ * Copyright (C) 1998-2014 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-11-06
- * modified: 2011-03-21 (vhfJDFromNSDate)
+ * modified: 2014-12-13 (asc. invariable node)
+ *           2011-03-21 (vhfJDFromNSDate)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
-#ifndef VHF_H_ASTROCOMMON
-#define VHF_H_ASTROCOMMON
+#ifndef CEN_H_ASTROCOMMON
+#define CEN_H_ASTROCOMMON
 
 #include <VHFShared/vhfCompatibility.h>     // CGFloat for OS X 10.4
 
 float sunNode(int year);
+double invariableNode(int year);    // ascending invariable node
 
 NSMutableData* reducedTable(NSData *tableData, int tableSize, double factor);
 NSMutableData* normalizedTable(NSData *table, int tableSize, BOOL positive);
@@ -110,4 +112,4 @@ double harmony(double obj, double obj1, double obj2);
 BOOL vhfIsDegreeInsideRange(double deg, double degFr, double degTo, BOOL retro);
 
 
-#endif // VHF_H_ASTROCOMMON
+#endif // CEN_H_ASTROCOMMON
