@@ -1,7 +1,7 @@
 /* astroCommon.m
  * Common astronomical functions
  *
- * Copyright (C) 1998-2009 by vhf interservice GmbH
+ * Copyright (C) 1998-2014 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-11-06
@@ -9,22 +9,22 @@
  *           2006-04-06 (Pholus ']' added, Pallas '[' corrected, new astro functions without NSCalendarDate)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
 #include <Foundation/Foundation.h>
@@ -42,13 +42,24 @@
  */
 float sunNode(int year)
 {
-    return 73.66670 + (float)(year - 1850) * 0.01396;
+    return 73.66670 + (float)(year - 1850) * 0.01396;   // 2014 = 75.956
+    //return 75.76  + (float)(year - 2000) * 0.01397;   // 2014 = 75.955
 }
 
+/* ascending invariable node
+ * Intersection between the invarianle plane and the ecliptic.
+ */
+double invariableNode(int year)
+{
+    //return 107.5822;    // J2000
+    return 102.95833 + (double)(year - 1750) * 0.01849548;  //1750 = 102.95833;
+}
+
+
 NSMutableData* reducedTable(NSData *tableData, int tableSize, double factor)
-{   int			i;
-    NSMutableData	*nTableData = [NSMutableData dataWithLength:tableSize * sizeof(double)];
-    double		*table = (double*)[tableData bytes], *nTable = [nTableData mutableBytes];
+{   int             i;
+    NSMutableData   *nTableData = [NSMutableData dataWithLength:tableSize * sizeof(double)];
+    double          *table = (double*)[tableData bytes], *nTable = [nTableData mutableBytes];
 
     /* reduce  */
     for ( i=0; i<tableSize; i++ )
@@ -909,31 +920,31 @@ float ac( NSCalendarDate *sideralTime, float lat)
  */
 NSString *planetSymbol(NSString *planet)
 {
-    if ( [planet isEqual:@"Sun"] )
+    if ( [planet isEqual:@"Sun"] )          // Sun
         return @"a";
-    if ( [planet isEqual:@"Mercury"] )
+    if ( [planet hasPrefix:@"Mer"] )        // Mer
         return @"b";
-    if ( [planet isEqual:@"Venus"] )
+    if ( [planet hasPrefix:@"Ven"] )        // Ven
         return @"c";
-    if ( [planet isEqual:@"Mars"] )
+    if ( [planet hasPrefix:@"Mar"] )        // Mar
         return @"d";
-    if ( [planet isEqual:@"Jupiter"] )
+    if ( [planet hasPrefix:@"Jup"] )        // Jup
         return @"e";
-    if ( [planet isEqual:@"Saturn"] )
+    if ( [planet hasPrefix:@"Sat"] )        // Sat
         return @"f";
-    if ( [planet isEqual:@"Uranus"] )
+    if ( [planet hasPrefix:@"Ura"] )        // Ura
         return @"g";
-    if ( [planet isEqual:@"Neptune"] )
+    if ( [planet hasPrefix:@"Nep"] )        // Nep
         return @"h";
-    if ( [planet isEqual:@"Pluto"] )
+    if ( [planet hasPrefix:@"Plu"] )        // Plu
         return @"i";
-    if ( [planet isEqual:@"Chiron"] )
+    if ( [planet hasPrefix:@"Chi"] )        // Chi
         return @"j";
-    if ( [planet isEqual:@"Moon"] )
+    if ( [planet hasPrefix:@"Moo"] )        // Moo
         return @"k";
-    if ( [planet isEqual:@"Lilith"] || [planet isEqual:@"Apogee"] || [planet isEqual:@"True Apogee"] )
+    if ( [planet isEqual:@"Lilith"] || [planet hasPrefix:@"Apo"] || [planet isEqual:@"True Apogee"] )
         return @"l";
-    if ( [planet isEqual:@"Node"] || [planet isEqual:@"North Node"] || [planet isEqual:@"True Node"] )
+    if ( [planet hasPrefix:@"Nod"]  || [planet isEqual:@"North Node"] || [planet isEqual:@"True Node"] )
         return @"m";
     if ( [planet isEqual:@"South Node"] )
         return @"n";
